<?php
// PHP STARTS HERE

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

global $post, $wp;

const HOME = 0;
const POST = 1;
const CATE = 2;
const TAXO = 3;
const TAG  = 4;

$current_url = add_query_arg( $wp->query_string, '', home_url( $wp->request ) );

$parse       = parse_url( $current_url );
$current_url = $parse['scheme'] . '://' . $parse['host'] . $parse['path'];
$current_url = str_replace( 'amp', '', $current_url );

$amps    = get_option( 'amps' );
$siteurl = get_site_url();
$type    = null;
if ( is_single() || is_page() ) {
	$type          = POST;
	$author        = get_user_meta( $post->post_author, 'first_name', true );
	$author_avatar = str_replace('<img', '<amp-img', get_avatar( $post->post_author, 16 ));
	$author_avatar = str_replace('/>', '></amp-img>', $author_avatar);
	$RAWcategories = get_the_category( $post->ID );
	$categories    = array();
	$shortcut_icon = AMP_URL . 'assets/img/touch/touch-icon-196x196.png';
	foreach ( $RAWcategories as $c ) {
		$categories[] = '<a href="' . get_category_link( $c->term_id ) . 'amp/">' . $c->cat_name . '</a>';
	}
	$RAWtags = wp_get_post_tags( $post->ID );
	$tags    = array();
	foreach ( $RAWtags as $t ) {
		$tags[] = '<a href="' . get_tag_link( $t->term_id ) . 'amp/">' . $t->name . '</a>';
	}

} else {
	$ampType = MAMP_Render::getAMPtype( $data );
	if ( $ampType == CATE ) {
		$type        = CATE;
		$args        = array(
			'posts_per_page'   => 5,
			'offset'           => 0,
			'category'         => '',
			'category_name'    => $data,
			'orderby'          => 'date',
			'order'            => 'DESC',
			'include'          => '',
			'exclude'          => '',
			'meta_key'         => '',
			'meta_value'       => '',
			'post_type'        => 'post',
			'post_mime_type'   => '',
			'post_parent'      => '',
			'author'           => '',
			'post_status'      => 'publish',
			'suppress_filters' => true
		);
		$posts_array = get_posts( $args );
	} elseif ( $ampType == TAG ) {
		$type        = TAG;
		$args        = array(
			'tax_query' => array(
				array(
					'taxonomy' => 'post_tag',
					'field'    => 'slug',
					'terms'    => $data
				)
			)
		);
		$posts_array = get_posts( $args );
	}
}

?>


<!DOCTYPE html>
<html class="no-js" ⚡>
<head>
	<meta charset="utf-8">
	<title><?php
		if ( $type == POST ) {
			echo $post->post_title;
		}
		?></title>
	<meta name="description" content="">
	<meta name="HandheldFriendly" content="True">
	<meta name="MobileOptimized" content="320">
	<meta name="viewport" content="width=device-width, minimum-scale=1, initial-scale=1, minimal-ui">

	<link rel="apple-touch-icon-precomposed" sizes="144x144"
	      href="<?php echo AMP_URL . 'assets/'; ?>img/touch/apple-touch-icon-144x144-precomposed.png">
	<link rel="apple-touch-icon-precomposed" sizes="114x114"
	      href="<?php echo AMP_URL . 'assets/'; ?>img/touch/apple-touch-icon-114x114-precomposed.png">
	<link rel="apple-touch-icon-precomposed" sizes="72x72"
	      href="<?php echo AMP_URL . 'assets/'; ?>img/touch/apple-touch-icon-72x72-precomposed.png">
	<link rel="apple-touch-icon-precomposed"
	      href="<?php echo AMP_URL . 'assets/'; ?>img/touch/apple-touch-icon-57x57-precomposed.png">
	<link rel="shortcut icon" sizes="196x196" href="<?php echo $shortcut_icon; ?>">
	<?php if ( isset( $amps['favico'] ) ) {
		if ( ! empty( $amps['favico'] ) ) { ?>
			<link rel="shortcut icon" href="<?php $amps['favico']; ?>">
		<?php }
	} ?>
	<!-- Tile icon for Win8 (144x144 + tile color) -->
	<meta name="msapplication-TileImage"
	      content="<?php echo AMP_URL . 'assets/'; ?>img/touch/apple-touch-icon-144x144-precomposed.png">
	<meta name="msapplication-TileColor" content="#222222">

	<!-- SEO: If mobile URL is different from desktop URL, add a canonical link to the desktop page -->
	<!---->
	<link rel="canonical" href="<?php echo $current_url; ?>">


	<!-- Add to homescreen for Chrome on Android -->
	<meta name="mobile-web-app-capable" content="yes">

	<!-- For iOS web apps. Delete if not needed. https://github.com/h5bp/mobile-boilerplate/issues/94 -->
	<!--
	<meta name="apple-mobile-web-app-capable" content="yes">
	<meta name="apple-mobile-web-app-status-bar-style" content="black">
	<meta name="apple-mobile-web-app-title" content="">
	-->

	<!-- This script prevents links from opening in Mobile Safari. https://gist.github.com/1042026 -->
	<!--
	<script>(function(a,b,c){if(c in b&&b[c]){var d,e=a.location,f=/^(a|html)$/i;a.addEventListener("click",function(a){d=a.target;while(!f.test(d.nodeName))d=d.parentNode;"href"in d&&(d.href.indexOf("http")||~d.href.indexOf(e.host))&&(a.preventDefault(),e.href=d.href)},!1)}})(document,window.navigator,"standalone")</script>
	-->
	
	<script type="application/ld+json">
    {
      "@context": "http://schema.org",
      "@type": "NewsArticle",
      "mainEntityOfPage": "<?php echo $current_url; ?>",
      "headline": "<?php if ( $type == POST ) { echo $post->post_title; } ?>",
	  <?php 
		$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'single-post-thumbnail' ); 
		$ldImage = !empty($image[0]) ? $image[0] : $shortcut_icon;
		$dimensions = MAMP_Render::getImageDimensions($ldImage);
		?>
      "image": {
          "@type": "ImageObject",
          "url": "<?php echo $ldImage; ?>",
		  "width": "<?php echo $dimensions['width']; ?>",
		  "height": "<?php echo $dimensions['height']; ?>"
      },
      "author": {
        "@type": "Person",
        "name": "<?php if ( $type == POST ) { echo !empty($author) ? $author : 'Admin'; } ?>"
      },
      "datePublished": "<?php if ( $type == POST ) { echo date( 'd-m-Y H:i:s', strtotime( $post->post_date ) ); } ?>",
      "dateModified": "<?php if ( $type == POST ) { echo date( 'd-m-Y H:i:s', strtotime( $post->post_modified ) ); } ?>",
	  "description": "<?php if ( $type == POST ) { echo do_shortcode( MAMP_Render::replaceForAMP(strip_tags($post->post_content))) ; } ?>",
      "publisher" : {
      	"@type": "Organization",
        "name": "<?php if ( $type == POST ) { echo !empty($author) ? $author : 'Admin'; } ?>",
			"logo": {
			  "@type": "ImageObject",
			  "url": "<?php echo $shortcut_icon; ?>",
			  "width": "<?php echo $dimensions['width']; ?>",
			  "height": "<?php echo $dimensions['height']; ?>"
			}
      }
    }
    </script>

	<script async src="https://cdn.ampproject.org/v0.js"></script>

	<!-- AMP Boilerplate -->
	<style amp-boilerplate>body{-webkit-animation:-amp-start 8s steps(1,end) 0s 1 normal both;-moz-animation:-amp-start 8s steps(1,end) 0s 1 normal both;-ms-animation:-amp-start 8s steps(1,end) 0s 1 normal both;animation:-amp-start 8s steps(1,end) 0s 1 normal both}@-webkit-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-moz-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-ms-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@-o-keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}@keyframes -amp-start{from{visibility:hidden}to{visibility:visible}}</style><noscript><style amp-boilerplate>body{-webkit-animation:none;-moz-animation:none;-ms-animation:none;animation:none}</style></noscript>

	<!-- Custom Design Changes -->
	<style amp-custom>
	
		html{font:400 14px/20px "Helvetica Neue",Helvetica,Arial,sans-serif;-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;background:#fff;color:#666;background-image:-webkit-radial-gradient(100% 100%,center,#fff,#fff);background-image:radial-gradient(100% 100% at center,#fff,#fff)}.uk-article:after,.uk-container:after,.uk-grid:after{clear:both}.uk-nav-offcanvas .uk-nav-header,.uk-nav-offcanvas>li>a{border-top:1px solid rgba(0,0,0,.3);text-shadow:0 1px 0 rgba(0,0,0,.5)}.uk-container{box-sizing:border-box;max-width:980px;padding:0 25px}@media (min-width:1220px){.uk-container{max-width:1200px;padding:0 35px}}.uk-container:after,.uk-container:before{content:"";display:table}.uk-container-center{margin-left:auto;margin-right:auto}.uk-margin-top{margin-top:15px}.uk-margin-large-bottom{margin-bottom:50px}.uk-article>:last-child,.uk-grid>*>:last-child{margin-bottom:0}.uk-grid{display:-ms-flexbox;display:-webkit-flex;display:flex;-ms-flex-wrap:wrap;-webkit-flex-wrap:wrap;flex-wrap:wrap;margin:0;padding:0;list-style:none}.uk-grid:after,.uk-grid:before{content:"";display:block;overflow:hidden}.uk-grid>*{-ms-flex:none;-webkit-flex:none;flex:none;margin:0;float:left;padding-left:25px}.uk-grid{margin-left:-25px}.uk-grid+.uk-grid,.uk-grid-margin,.uk-grid>*>.uk-panel+.uk-panel{margin-top:25px}@media (min-width:1220px){.uk-grid{margin-left:-35px}.uk-grid>*{padding-left:35px}.uk-grid+.uk-grid,.uk-grid-margin,.uk-grid>*>.uk-panel+.uk-panel{margin-top:35px}}@media (min-width:768px){.uk-grid-divider>[class*=uk-width-medium-]:not(.uk-width-medium-1-1):nth-child(n+2){border-left:1px solid #e5e5e5}.uk-width-medium-1-1{width:100%}}.uk-article:after,.uk-article:before{content:"";display:table}.uk-article+.uk-article{margin-top:50px}.uk-article-title{font-size:36px;line-height:42px;font-weight:300;text-transform:none}.uk-article-meta,.uk-nav li>a>div{font-size:12px;line-height:18px}.uk-article-title a{color:inherit;text-decoration:none}.uk-article-meta{color:#999}.uk-offcanvas-bar{position:fixed;top:0;bottom:0;left:0;-webkit-transform:translateX(-100%);transform:translateX(-100%);z-index:1001;width:270px;max-width:100%;background:#333;overflow-y:auto;-webkit-overflow-scrolling:touch;-webkit-transition:-webkit-transform .3s ease-in-out;transition:transform .3s ease-in-out;-ms-scroll-chaining:none}.uk-offcanvas-bar-flip:after,.uk-offcanvas-bar:after{width:1px;background:rgba(0,0,0,.6);box-shadow:0 0 5px 2px rgba(0,0,0,.6)}.uk-offcanvas.uk-active .uk-offcanvas-bar.uk-offcanvas-bar-show{-webkit-transform:translateX(0);transform:translateX(0)}.uk-offcanvas-bar-flip{left:auto;right:0;-webkit-transform:translateX(100%);transform:translateX(100%)}.uk-offcanvas .uk-panel{margin:20px 15px;color:#777;text-shadow:0 1px 0 rgba(0,0,0,.5)}.uk-offcanvas .uk-panel a:not([class]),.uk-offcanvas .uk-panel-title{color:#ccc}.uk-offcanvas .uk-panel a:not([class]):hover{color:#fff}.uk-offcanvas-bar:after{content:"";display:block;position:absolute;top:0;bottom:0;right:0}.uk-offcanvas-bar-flip:after{right:auto;left:0}.uk-nav,.uk-nav ul{margin:0;padding:0;list-style:none}.uk-nav li>a{display:block;text-decoration:none}.uk-nav>li>a{padding:3px 15px}.uk-nav ul{padding-left:15px}.uk-nav ul a{padding:2px 0}.uk-nav-offcanvas>li>a{color:#ccc;padding:10px 15px;box-shadow:inset 0 1px 0 rgba(255,255,255,.05)}.uk-nav-offcanvas>.uk-open>a,html:not(.uk-touch) .uk-nav-offcanvas>li>a:focus,html:not(.uk-touch) .uk-nav-offcanvas>li>a:hover{background:#404040;color:#fff;outline:0}html .uk-nav.uk-nav-offcanvas>li.uk-active>a{background:#1a1a1a;color:#fff;box-shadow:inset 0 1px 3px rgba(0,0,0,.3)}.uk-nav-offcanvas .uk-nav-header{color:#777;margin-top:0;background:#404040;box-shadow:inset 0 1px 0 rgba(255,255,255,.05)}.uk-nav-offcanvas .uk-nav-divider{border-top:1px solid rgba(255,255,255,.01);margin:0;height:4px;background:rgba(0,0,0,.2);box-shadow:inset 0 1px 3px rgba(0,0,0,.3)}.uk-nav-offcanvas ul a{color:#ccc}html:not(.uk-touch) .uk-nav-offcanvas ul a:hover{color:#fff}.uk-nav-offcanvas{border-bottom:1px solid rgba(0,0,0,.3);box-shadow:0 1px 0 rgba(255,255,255,.05)}.uk-nav-offcanvas .uk-nav-sub{border-top:1px solid rgba(0,0,0,.3);box-shadow:inset 0 1px 0 rgba(255,255,255,.05)}.uk-nav-side>li.uk-active>a{background:#009dd8;color:#fff;box-shadow:inset 0 2px 4px rgba(0,0,0,.2);text-shadow:0 -1px 0 rgba(0,0,0,.2)}

@font-face{font-family:'Droid Sans';font-style:normal;font-weight:400;src:local('Droid Sans'),local('DroidSans'),url(https://fonts.gstatic.com/s/droidsans/v6/s-BiyweUPV0v-yRb-cjciPk_vArhqVIZ0nv9q090hN8.woff2) format('woff2');unicode-range:U+0000-00FF,U+0131,U+0152-0153,U+02C6,U+02DA,U+02DC,U+2000-206F,U+2074,U+20AC,U+2212,U+2215,U+E0FF,U+EFFD,U+F000}@font-face{font-family:Pacifico;font-style:normal;font-weight:400;src:local('Pacifico Regular'),local('Pacifico-Regular'),url(https://fonts.gstatic.com/s/pacifico/v7/Q_Z9mv4hySLTMoMjnk_rCfesZW2xOQ-xsNqO47m55DA.woff2) format('woff2');unicode-range:U+0000-00FF,U+0131,U+0152-0153,U+02C6,U+02DA,U+02DC,U+2000-206F,U+2074,U+20AC,U+2212,U+2215,U+E0FF,U+EFFD,U+F000}input[type=checkbox]:checked:before{margin:1px 0 0}input[type=checkbox]{width:15px;height:15px}.uk-grid *{font-family:'Droid Sans',sans-serif}small.hand{font-family:Pacifico,cursive;color:#98AC29}small.text-desc{font-size:12px;font-style:italic;font-weight:400}nav.navbar.amp{height:60px}.amp-container,.amp-site-name{max-width:840px}.amp-site-name{margin-left:auto;margin-right:auto;padding:15px 35px 0;-webkit-box-sizing:border-box;-moz-box-sizing:border-box;box-sizing:border-box;font-size:20px;font-weight:700;color:#fff}.uk-article-title{font-size:36px;font-weight:700;margin-top:25px;margin-bottom:25px}.uk-article-content{font-size:16px;font-weight:400;word-spacing:1px}p.uk-article-meta{font-size:15px;font-style:italic;margin-bottom:25px}img.alignleft{float:left}img.alignright{float:right}img.aligncenter{clear:both;display:block;margin:0 auto 28px}body:not(.custom-background-image):after,body:not(.custom-background-image):before{height:0}.uk-article{margin-bottom:35px}input#mobile-test-url{width:270px}.avatar-16{margin:0 5px;border-radius:5px}.sp-replacer {height: 15px;border-radius: 5px;}.sp-preview-inner,.sp-preview {height: 12px ;}

		<?php if (isset($amps['color_header'])) { ?>
		.navbar.amp {
			background: <?php echo $amps['color_header']; ?> ;
		}
		<?php } ?>
		<?php if (isset($amps['color_header_text'])) { ?>
		.amp-site-name a {
			color: <?php echo $amps['color_header_text']; ?> ;
			text-decoration: none ;
		}
		<?php } ?>
		<?php if (isset($amps['color_article_title'])) { ?>
		.uk-article-title a {
			color: <?php echo $amps['color_article_title']; ?> ;
		}
		<?php } ?>
		<?php if (isset($amps['color_article_text'])) { ?>
		.uk-article-content, .uk-article-content *{
			color: <?php echo $amps['color_article_text']; ?> ;
		}
		<?php } ?>
	</style>
</head>
<body>
<!-- Header -->
<nav class="navbar amp">
	<div class="amp-site-name">
		<a href="<?php echo $siteurl; ?>"><?php if ( isset( $amps['logo_image'] ) ) {
				if ( ! empty( $amps['logo_image'] ) ) { ?>
					<amp-img src="<?php echo $amps['logo_image']; ?>" alt="Logo" height="20" width="25" class="amp-logo-image"></amp-img>
				<?php }
			} ?>
			<?php echo get_bloginfo( "name" ); ?></a>
	</div>
</nav>

<!-- Content -->
<div class="uk-container uk-container-center uk-margin-top uk-margin-large-bottom amp-container">

	<div class="uk-grid" data-uk-grid-margin>
		<div class="uk-width-medium-1-1">


			<?php if ( $type == POST || $type == HOME ) { ?>
				<article class="uk-article">

					<h1 class="uk-article-title">
						<a href="#"><?php
							if ( $type == POST ) {
								echo $post->post_title;
							}
							?></a>
					</h1>

					<?php if ( $type == POST ) { ?>
						<p class="uk-article-meta">Written by <?php echo $author_avatar; ?><?php echo $author; ?>
							on <?php echo date( 'd F Y', strtotime( $post->post_date ) ); ?>.
							♦ <?php echo join( ', ', $categories ); ?> &nbsp;♦ <?php echo join( ', ', $tags ); ?></p>
					<?php } ?>

					<?php if ( has_post_thumbnail( $post->ID ) ): ?>
						<?php $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'single-post-thumbnail' ); ?>
						<p>
							<amp-img height="300" src="<?php echo $image[0]; ?>" alt=""></amp-img>
						</p>
					<?php endif; ?>

					<div class="uk-article-content">
						<?php
						if ( $type == POST ) {
							echo do_shortcode( MAMP_Render::replaceForAMP($post->post_content)  );
						}
						?>
					</div>


				</article>
			<?php } elseif ( $type == CATE || $type == TAG ) { ?>
				<?php if ( $type == CATE ) { ?>
					<h1>Category: <?php echo $data; ?></h1>
					<hr>
				<?php } elseif ( $type == TAG ) { ?>
					<h1>Tag: <?php echo $data; ?></h1>
					<hr>
				<?php } ?>
				<?php foreach ( $posts_array as $post ) {

					$author        = get_user_meta( $post->post_author, 'first_name', true );
					$author_avatar = get_avatar( $post->post_author, 16 );
					$RAWcategories = get_the_category( $post->ID );
					$categories    = array();
					foreach ( $RAWcategories as $c ) {
						$categories[] = '<a href="' . get_category_link( $c->term_id ) . 'amp/">' . $c->cat_name . '</a>';
					}
					$RAWtags = wp_get_post_tags( $post->ID );
					$tags    = array();
					foreach ( $RAWtags as $t ) {
						$tags[] = '<a href="' . get_tag_link( $t->term_id ) . 'amp/">' . $t->name . '</a>';
					}

					?>
					<article class="uk-article">

						<h1 class="uk-article-title">
							<a href="#"><?php echo $post->post_title; ?></a>
						</h1>

						<p class="uk-article-meta">Written by <?php echo $author_avatar; ?><?php echo $author; ?>
							on <?php echo date( 'd F Y', strtotime( $post->post_date ) ); ?>.
							♦ <?php echo join( ', ', $categories ); ?> &nbsp;♦ <?php echo join( ', ', $tags ); ?></p>

						<?php if ( has_post_thumbnail( $post->ID ) ): ?>
							<?php $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'single-post-thumbnail' ); ?>
							<p>
								<amp-img height="300" src="<?php echo $image[0]; ?>" alt=""></amp-img>
							</p>
						<?php endif; ?>

						<p class="uk-article-content">
							<?php echo do_shortcode( MAMP_Render::replaceForAMP($post->post_content) ); ?>
						</p>

					</article>

					<hr>
				<?php } ?>
			<?php } ?>
		</div>
	</div>

</div>

<div id="offcanvas" class="uk-offcanvas">
	<div class="uk-offcanvas-bar">
		<ul class="uk-nav uk-nav-offcanvas">
			<li>
				<a href="layouts_frontpage.html">Frontpage</a>
			</li>
			<li>
				<a href="layouts_portfolio.html">Portfolio</a>
			</li>
			<li class="uk-active">
				<a href="layouts_blog.html">Blog</a>
			</li>
			<li>
				<a href="layouts_documentation.html">Documentation</a>
			</li>
			<li>
				<a href="layouts_contact.html">Contact</a>
			</li>
			<li>
				<a href="layouts_login.html">Login</a>
			</li>
		</ul>
	</div>
</div>
<!-- /Content -->

</body>
</html>

